@@ -11,4 +11,14 @@
 #' @keywords internal
 .dummy_use_rlang <- function() rlang::is_true(TRUE)
 
+#' @keywords internal
+.dummy_use_metafor <- function() metafor::rma(yi = 1:10, vi = 1:10)
+
+#' @keywords internal
+.dummy_use_purrr <- function() purrr::map_chr(1:10, ~.x)
+
+#' @keywords internal
+.dummy_use_tidyverse <- function() tidyverse::tidyverse_packages()
+
+
 # nolint end: box_usage_linter, unused_declared_object_linter.
