@@ -12,16 +12,14 @@ get_runtime_method_modules <- function() {
 }
 
 #' @title List methods
-#' @description Print all runtime methods supported by ARTMA into the console.
+#' @description Print all runtime methods supported by artma into the console.
 #' @return `NULL` Prints the available methods into the console.
 #' @export
 methods.list <- function() {
-  static_setup() # nolint: box_usage_linter.
-
   box::use(artma / const[CONST])
 
   RUNTIME_METHOD_MODULES <- get_runtime_method_modules()
 
-  cli::cli_text(cli::format_inline(("{CONST$PACKAGE_NAME} ({packageVersion(CONST$PACKAGE_NAME)}) supports the following runtime methods:")))
+  cli::cli_h1("{.file {CONST$PACKAGE_NAME}} ({packageVersion(CONST$PACKAGE_NAME)}) runtime methods:")
   cli::cli_ul(names(RUNTIME_METHOD_MODULES))
 }
